@@ -28,11 +28,13 @@ from hyperspy.component import Component
 from hyperspy.misc.eels.hartree_slater_gos import HartreeSlaterGOS
 from hyperspy.misc.eels.hydrogenic_gos import HydrogenicGOS
 from hyperspy.misc.eels.effective_angle import effective_angle
+from hyperspy.ui_registry import add_gui_method
 
 
 _logger = logging.getLogger(__name__)
 
 
+@add_gui_method(toolkey="EELSCLEdge_Component")
 class EELSCLEdge(Component):
 
     """EELS core loss ionisation edge from hydrogenic or tabulated
@@ -81,12 +83,10 @@ class EELSCLEdge(Component):
         Decreasing the value increases the level of smoothing.
 
     fine_structure_active : bool
-        Activates/deactivates the fine structure feature. Its
-        default value can be choosen in the preferences.
+        Activates/deactivates the fine structure feature.
 
     """
-    _fine_structure_smoothing = \
-        preferences.EELS.fine_structure_smoothing
+    _fine_structure_smoothing = 0.3
 
     def __init__(self, element_subshell, GOS=None):
         # Declare the parameters
@@ -103,8 +103,8 @@ class EELSCLEdge(Component):
         self.name = "_".join([self.element, self.subshell])
         self.energy_scale = None
         self.effective_angle.free = False
-        self.fine_structure_active = preferences.EELS.fine_structure_active
-        self.fine_structure_width = preferences.EELS.fine_structure_width
+        self.fine_structure_active = False
+        self.fine_structure_width = 30.
         self.fine_structure_coeff.ext_force_positive = False
         self.GOS = None
         # Set initial actions
@@ -384,48 +384,3 @@ class EELSCLEdge(Component):
             '_', ' ') + ' fine structure'
 
         return s
-
-    def notebook_interaction(self, display=True):
-
-        from ipywidgets import (Checkbox, FloatSlider, VBox)
-        from traitlets import TraitError as TraitletError
-        from IPython.display import display as ip_display
-
-        try:
-            active = Checkbox(description='active', value=self.active)
-
-            def on_active_change(change):
-                self.active = change['new']
-            active.observe(on_active_change, names='value')
-
-            fine_structure = Checkbox(description='Fine structure',
-                                      value=self.fine_structure_active)
-
-            def on_fine_structure_active_change(change):
-                self.fine_structure_active = change['new']
-            fine_structure.observe(on_fine_structure_active_change,
-                                   names='value')
-
-            fs_smoothing = FloatSlider(description='Fine structure smoothing',
-                                       min=0, max=1, step=0.001,
-                                       value=self.fine_structure_smoothing)
-
-            def on_fs_smoothing_change(change):
-                self.fine_structure_smoothing = change['new']
-            fs_smoothing.observe(on_fs_smoothing_change, names='value')
-
-            container = VBox([active, fine_structure, fs_smoothing])
-            for parameter in [self.intensity, self.effective_angle,
-                              self.onset_energy]:
-                container.children += parameter.notebook_interaction(False),
-
-            if not display:
-                return container
-            ip_display(container)
-        except TraitletError:
-            if display:
-                print('This function is only avialable when running in a'
-                      ' notebook')
-            else:
-                raise
-    notebook_interaction.__doc__ = Component.notebook_interaction.__doc__
