@@ -19,8 +19,10 @@
 
 from scipy.interpolate import interp1d
 from hyperspy.component import Component
+from hyperspy.ui_registry import add_gui_method
 
 
+@add_gui_method(toolkey="ScalableFixedPattern_Component")
 class ScalableFixedPattern(Component):
 
     """Fixed pattern component with interpolation support.
@@ -44,7 +46,7 @@ class ScalableFixedPattern(Component):
 
     .. code-block:: ipython
 
-        In [1]: s = load('my_spectrum.hdf5')
+        In [1]: s = load('my_spectrum.hspy')
         In [2]: my_fixed_pattern = components.ScalableFixedPattern(s))
 
     Attributes
@@ -125,33 +127,3 @@ class ScalableFixedPattern(Component):
 
     def grad_yscale(self, x):
         return self.function(x) / self.yscale.value
-
-    def notebook_interaction(self, display=True):
-        from ipywidgets import Checkbox
-        from traitlets import TraitError as TraitletError
-        from IPython.display import display as ip_display
-
-        try:
-            container = super(ScalableFixedPattern,
-                              self).notebook_interaction(display=False)
-            interpolate = Checkbox(description='interpolate',
-                                   value=self.interpolate)
-
-            def on_interpolate_change(change):
-                self.interpolate = change['new']
-
-            interpolate.observe(on_interpolate_change, names='value')
-
-            container.children = (container.children[0], interpolate) + \
-                container.children[1:]
-
-            if not display:
-                return container
-            ip_display(container)
-        except TraitletError:
-            if display:
-                print('This function is only avialable when running in a'
-                      ' notebook')
-            else:
-                raise
-    notebook_interaction.__doc__ = Component.notebook_interaction.__doc__
