@@ -34,6 +34,7 @@ from hyperspy.exceptions import NavigationDimensionError
 from hyperspy.misc.export_dictionary import export_to_dictionary, \
     load_from_dictionary
 from hyperspy.events import Events, Event
+from hyperspy.ui_registry import add_gui_method, register_toolkey
 
 import logging
 
@@ -52,6 +53,7 @@ class NoneFloat(t.CFloat):   # Lazy solution, but usable
         return super(NoneFloat, self).validate(object, name, value)
 
 
+@add_gui_method(toolkey="Parameter")
 class Parameter(t.HasTraits):
 
     """Model parameter
@@ -625,7 +627,7 @@ class Parameter(t.HasTraits):
         """
         self.as_signal().plot(**kwargs)
 
-    def export(self, folder=None, name=None, format=None,
+    def export(self, folder=None, name=None, format="hspy",
                save_std=False):
         """Save the data to a file.
 
@@ -643,10 +645,12 @@ class Parameter(t.HasTraits):
               modified by appending a number to the file path.
         save_std : bool
             If True, also the standard deviation will be saved
+        format: str
+            The extension of any file format supported by HyperSpy, default hspy
 
         """
         if format is None:
-            format = preferences.General.default_export_format
+            format = "hspy"
         if name is None:
             name = self.component.name + '_' + self.name
         filename = incremental_filename(slugify(name) + '.' + format)
@@ -704,119 +708,8 @@ class Parameter(t.HasTraits):
         view = View(editable_traits, buttons=['OK', 'Cancel'])
         return view
 
-    def _interactive_slider_bounds(self, index=None):
-        """Guesstimates the bounds for the slider. They will probably have to
-        be changed later by the user.
-        """
-        fraction = 10.
-        _min, _max, step = None, None, None
-        value = self.value if index is None else self.value[index]
-        if self.bmin is not None:
-            _min = self.bmin
-        if self.bmax is not None:
-            _max = self.bmax
-        if _max is None and _min is not None:
-            _max = value + fraction * (value - _min)
-        if _min is None and _max is not None:
-            _min = value - fraction * (_max - value)
-        if _min is None and _max is None:
-            if self is self.component._position:
-                axis = self._axes_manager.signal_axes[-1]
-                _min = axis.axis.min()
-                _max = axis.axis.max()
-                step = np.abs(axis.scale)
-            else:
-                _max = value + np.abs(value * fraction)
-                _min = value - np.abs(value * fraction)
-        if step is None:
-            step = (_max - _min) * 0.001
-        return {'min': _min, 'max': _max, 'step': step}
-
-    def _interactive_update(self, value=None, index=None):
-        """Callback function for the widgets, to update the value
-        """
-        if value is not None:
-            if index is None:
-                self.value = value['new']
-            else:
-                self.value = self.value[:index] + (value['new'],) +\
-                    self.value[index + 1:]
-
-    def notebook_interaction(self, display=True):
-        """Creates interactive notebook widgets for the parameter, if
-        available.
-        Requires `ipywidgets` to be installed.
-        Parameters
-        ----------
-        display : bool
-            if True (default), attempts to display the parameter widget.
-            Otherwise returns the formatted widget object.
-        """
-        from ipywidgets import VBox
-        from traitlets import TraitError as TraitletError
-        from IPython.display import display as ip_display
-        try:
-            if self._number_of_elements == 1:
-                container = self._create_notebook_widget()
-            else:
-                children = [self._create_notebook_widget(index=i) for i in
-                            range(self._number_of_elements)]
-                container = VBox(children)
-            if not display:
-                return container
-            ip_display(container)
-        except TraitletError:
-            if display:
-                _logger.info('This function is only avialable when running in'
-                             ' a notebook')
-            else:
-                raise
-
-    def _create_notebook_widget(self, index=None):
-
-        from ipywidgets import (FloatSlider, FloatText, Layout, HBox)
-
-        widget_bounds = self._interactive_slider_bounds(index=index)
-        thismin = FloatText(value=widget_bounds['min'],
-                            description='min',
-                            layout=Layout(flex='0 1 auto',
-                                          width='auto'),)
-        thismax = FloatText(value=widget_bounds['max'],
-                            description='max',
-                            layout=Layout(flex='0 1 auto',
-                                          width='auto'),)
-        current_value = self.value if index is None else self.value[index]
-        current_name = self.name
-        if index is not None:
-            current_name += '_{}'.format(index)
-        widget = FloatSlider(value=current_value,
-                             min=thismin.value,
-                             max=thismax.value,
-                             step=widget_bounds['step'],
-                             description=current_name,
-                             layout=Layout(flex='1 1 auto', width='auto'))
-
-        def on_min_change(change):
-            if widget.max > change['new']:
-                widget.min = change['new']
-                widget.step = np.abs(widget.max - widget.min) * 0.001
-
-        def on_max_change(change):
-            if widget.min < change['new']:
-                widget.max = change['new']
-                widget.step = np.abs(widget.max - widget.min) * 0.001
-
-        thismin.observe(on_min_change, names='value')
-        thismax.observe(on_max_change, names='value')
-
-        this_observed = functools.partial(self._interactive_update,
-                                          index=index)
-
-        widget.observe(this_observed, names='value')
-        container = HBox((thismin, widget, thismax))
-        return container
-
 
+@add_gui_method(toolkey="Component")
 class Component(t.HasTraits):
     __axes_manager = None
 
@@ -896,13 +789,14 @@ class Component(t.HasTraits):
 
     def _set_name(self, value):
         old_value = self._name
+        if old_value == value:
+            return
         if self.model:
             for component in self.model:
                 if value == component.name:
-                    if not (component is self):
-                        raise ValueError(
-                            "Another component already has "
-                            "the name " + str(value))
+                    raise ValueError(
+                        "Another component already has "
+                        "the name " + str(value))
             self._name = value
             setattr(self.model.components, slugify(
                 value, valid_variable_name=True), self)
@@ -1056,7 +950,7 @@ class Component(t.HasTraits):
         for parameter in parameters:
             parameter.plot()
 
-    def export(self, folder=None, format=None, save_std=False,
+    def export(self, folder=None, format="hspy", save_std=False,
                only_free=True):
         """Plot the value of the parameters of the model
 
@@ -1067,12 +961,7 @@ class Component(t.HasTraits):
             `None` the
             current folder is used by default.
         format : str
-            The format to which the data will be exported. It must be
-            the
-            extension of any format supported by HyperSpy. If None, the
-            default
-            format for exporting as defined in the `Preferences` will be
-             used.
+            The extension of the file format, default "hspy".
         save_std : bool
             If True, also the standard deviation will be saved.
         only_free : bool
@@ -1105,10 +994,10 @@ class Component(t.HasTraits):
                 is not None else 0
             if parameter.twin is None:
                 if dim <= 1:
-                    return ('%s = %s ± %s %s' % (parameter.name,
-                                                 parameter.value,
-                                                 parameter.std,
-                                                 parameter.units))
+                    print('%s = %s ± %s %s' % (parameter.name,
+                                               parameter.value,
+                                               parameter.std,
+                                               parameter.units))
 
     def __call__(self):
         """Returns the corresponding model for the current coordinates
@@ -1272,7 +1161,9 @@ class Component(t.HasTraits):
             the parameters of the component, to be later used for setting up
             correct twins.
         """
+
         if dic['_id_name'] == self._id_name:
+            load_from_dictionary(self, dic)
             id_dict = {}
             for p in dic['parameters']:
                 idname = p['_id_name']
@@ -1283,42 +1174,7 @@ class Component(t.HasTraits):
                 else:
                     raise ValueError(
                         "_id_name of parameters in component and dictionary do not match")
-            load_from_dictionary(self, dic)
             return id_dict
         else:
             raise ValueError( "_id_name of component and dictionary do not match, \ncomponent._id_name = %s\
                     \ndictionary['_id_name'] = %s" % (self._id_name, dic['_id_name']))
-
-    def notebook_interaction(self, display=True):
-        """Creates interactive notebook widgets for all component parameters,
-        if available.
-        Requires `ipywidgets` to be installed.
-        Parameters
-        ----------
-        display : bool
-            if True (default), attempts to display the widgets.
-            Otherwise returns the formatted widget object.
-        """
-        from ipywidgets import (Checkbox, VBox)
-        from traitlets import TraitError as TraitletError
-        from IPython.display import display as ip_display
-        try:
-            active = Checkbox(description='active', value=self.active)
-
-            def on_active_change(change):
-                self.active = change['new']
-            active.observe(on_active_change, names='value')
-
-            container = VBox([active])
-            for parameter in self.parameters:
-                container.children += parameter.notebook_interaction(False),
-
-            if not display:
-                return container
-            ip_display(container)
-        except TraitletError:
-            if display:
-                _logger.info('This function is only avialable when running in'
-                             ' a notebook')
-            else:
-                raise
