@@ -21,3 +21,10 @@ OUT_ARG = \
             If None, a new Signal is created with the result of the operation
             and returned (default). If a Signal is passed, it is used to
             receive the output of the operation, and nothing is returned."""
+
+NAN_FUNC = \
+    """Identical to {0} except ignores missing (NaN) values.
+       The full documentation follows:
+
+       -------------------- {0} --------------------
+        {1} """
