@@ -212,6 +212,24 @@ def file_reader(filename, endianess='<', **kwds):
     dictionary = {'data': data,
                   'axes': axes,
                   'metadata': metadata,
-                  'original_metadata': original_metadata, }
+                  'original_metadata': original_metadata,
+                  'mapping': mapping}
 
     return [dictionary, ]
+
+mapping = {
+    'fei_header.a_tilt':
+    ("Acquisition_instrument.TEM.Stage.tilt_alpha", None),
+    'fei_header.b_tilt':
+    ("Acquisition_instrument.TEM.Stage.tilt_beta", None),
+    'fei_header.x_stage':
+    ("Acquisition_instrument.TEM.Stage.x", None),
+    'fei_header.y_stage':
+    ("Acquisition_instrument.TEM.Stage.y", None),
+    'fei_header.z_stage':
+    ("Acquisition_instrument.TEM.Stage.z", None),
+    'fei_header.exp_time':
+    ("Acquisition_instrument.TEM.Detector.Camera.exposure", None),
+    'fei_header.magnification':
+    ("Acquisition_instrument.TEM.magnification", None),
+}
