@@ -27,8 +27,8 @@ import collections
 import tempfile
 import unicodedata
 from contextlib import contextmanager
-from ..misc.signal_tools import broadcast_signals
-from ..exceptions import VisibleDeprecationWarning
+from hyperspy.misc.signal_tools import broadcast_signals
+from hyperspy.exceptions import VisibleDeprecationWarning
 
 import numpy as np
 
@@ -681,10 +681,7 @@ def find_subclasses(mod, cls):
 
 
 def isiterable(obj):
-    if isinstance(obj, collections.Iterable):
-        return True
-    else:
-        return False
+    return isinstance(obj, collections.Iterable)
 
 
 def ordinal(value):
@@ -986,7 +983,8 @@ def map_result_construction(signal,
                             ragged,
                             sig_shape=None,
                             lazy=False):
-    from hyperspy.signals import (BaseSignal, LazySignal)
+    from hyperspy.signals import BaseSignal
+    from hyperspy._lazy_signals import LazySignal
     res = None
     if inplace:
         sig = signal
@@ -1012,6 +1010,8 @@ def map_result_construction(signal,
                 len(sig_shape) - sig.axes_manager.signal_dimension, 0, -1):
             sig.axes_manager._append_axis(sig_shape[-ind], navigate=False)
     sig.get_dimensions_from_data()
+    if not sig.axes_manager._axes:
+        add_scalar_axis(sig)
     return res
 
 
@@ -1030,3 +1030,32 @@ def multiply(iterable):
     for i in iterable:
         prod *= i
     return prod
+
+
+def iterable_not_string(thing):
+    return isinstance(thing, collections.Iterable) and \
+        not isinstance(thing, str)
+
+
+def signal_range_from_roi(signal_range):
+    from hyperspy.roi import SpanROI
+    if isinstance(signal_range, SpanROI):
+        return (signal_range.left, signal_range.right)
+    else:
+        return signal_range
+
+
+def deprecation_warning(msg):
+    warnings.warn(msg, VisibleDeprecationWarning)
+
+
+def add_scalar_axis(signal):
+    am = signal.axes_manager
+    from hyperspy.signal import BaseSignal
+    signal.__class__ = BaseSignal
+    am.remove(am._axes)
+    am._append_axis(size=1,
+                    scale=1,
+                    offset=0,
+                    name="Scalar",
+                    navigate=False)
