@@ -66,6 +66,14 @@ class EELSModel(Model1D):
                  auto_add_edges=True, ll=None,
                  GOS=None, dictionary=None):
         Model1D.__init__(self, signal1D)
+
+        # When automatically setting the fine structure energy regions,
+        # the fine structure of an EELS edge component is automatically
+        # disable if the next ionisation edge onset distance to the
+        # higher energy side of the fine structure region is lower that
+        # the value of this parameter
+        self._min_distance_between_edges_for_fine_structure = 0
+        self._preedge_safe_window_width = 2
         self.signal1D = signal1D
         self._suspend_auto_fine_structure_width = False
         self.convolved = False
@@ -213,8 +221,7 @@ class EELSModel(Model1D):
 
     def resolve_fine_structure(
             self,
-            preedge_safe_window_width=preferences.EELS.
-            preedge_safe_window_width,
+            preedge_safe_window_width=2,
             i1=0):
         """Adjust the fine structure of all edges to avoid overlapping
 
@@ -225,7 +232,8 @@ class EELSModel(Model1D):
         ----------
         preedge_safe_window_width : float
             minimum distance between the fine structure of an ionization edge
-            and that of the following one.
+            and that of the following one. Default 2 (eV).
+
         """
 
         if self._suspend_auto_fine_structure_width is True:
@@ -247,11 +255,11 @@ class EELSModel(Model1D):
                     self._active_edges[i2].onset_energy.value -
                     self._active_edges[i1].onset_energy.value)
                 if (self._active_edges[i1].fine_structure_width >
-                        distance_between_edges - preedge_safe_window_width):
-                    min_d = preferences.EELS.\
-                        min_distance_between_edges_for_fine_structure
+                        distance_between_edges -
+                        self._preedge_safe_window_width):
+                    min_d = self._min_distance_between_edges_for_fine_structure
                     if (distance_between_edges -
-                            preedge_safe_window_width) <= min_d:
+                            self._preedge_safe_window_width) <= min_d:
                         _logger.info((
                             "Automatically deactivating the fine structure "
                             "of edge number %d to avoid conflicts with edge "
@@ -262,7 +270,8 @@ class EELSModel(Model1D):
                         self.resolve_fine_structure(i1=i2)
                     else:
                         new_fine_structure_width = (
-                            distance_between_edges - preedge_safe_window_width)
+                            distance_between_edges -
+                            self._preedge_safe_window_width)
                         _logger.info((
                             "Automatically changing the fine structure "
                             "width of edge %d from %s eV to %s eV to avoid "
@@ -421,7 +430,7 @@ class EELSModel(Model1D):
         if iee is not None:
             to_disable = [edge for edge in self._active_edges
                           if edge.onset_energy.value >= iee]
-            E2 = iee - preferences.EELS.preedge_safe_window_width
+            E2 = iee - self._preedge_safe_window_width
             self.disable_edges(to_disable)
         else:
             E2 = None
@@ -470,7 +479,7 @@ class EELSModel(Model1D):
                 E2 = ea[-1]
             else:
                 E2 = E2 - \
-                    preferences.EELS.preedge_safe_window_width
+                    self._preedge_safe_window_width
 
         if not powerlaw.estimate_parameters(
                 self.signal, E1, E2, only_current=False):
@@ -485,7 +494,7 @@ class EELSModel(Model1D):
         ea = self.axis.axis[self.channel_switches]
         if start_energy is None:
             start_energy = ea[0]
-        preedge_safe_window_width = preferences.EELS.preedge_safe_window_width
+        preedge_safe_window_width = self._preedge_safe_window_width
         # Declare variables
         active_edges = self._active_edges
         edge = active_edges[edgenumber]
@@ -509,7 +518,7 @@ class EELSModel(Model1D):
         else:
             nextedgeenergy = (
                 active_edges[edgenumber + i].onset_energy.value -
-                preedge_safe_window_width)
+                self._preedge_safe_window_width)
 
         # Backup the fsstate
         to_activate_fs = []
