@@ -17,7 +17,6 @@
 
 import numpy as np
 import pytest
-from matplotlib.testing.decorators import cleanup
 
 from hyperspy.misc.test_utils import update_close_figure, sanitize_dict
 from hyperspy.signals import Signal2D, Signal1D
@@ -27,6 +26,7 @@ from hyperspy.drawing.marker import dict2marker
 
 default_tol = 2.0
 baseline_dir = 'plot_markers'
+style_pytest_mpl = 'default'
 
 
 class TestMarkers:
@@ -136,7 +136,7 @@ class TestMarkers:
         m = markers.point(x=5, y=5)
         s.add_marker(m, plot_marker=False)
 
-    def test_add_marker_signal1d_navigation_dim(self):
+    def test_add_marker_signal1d_navigation_dim(self, mpl_cleanup):
         s = Signal1D(np.zeros((3, 50, 50)))
         m0 = markers.point(5, 5)
         m1 = markers.point((5, 10), (10, 15))
@@ -146,7 +146,7 @@ class TestMarkers:
             s.add_marker(m1)
         s.add_marker(m2)
 
-    def test_add_marker_signal2d_navigation_dim(self):
+    def test_add_marker_signal2d_navigation_dim(self, mpl_cleanup):
         s = Signal2D(np.zeros((3, 50, 50)))
         m0 = markers.point(5, 5)
         m1 = markers.point((5, 10), (10, 15))
@@ -156,7 +156,7 @@ class TestMarkers:
             s.add_marker(m1)
         s.add_marker(m2)
 
-    def test_add_markers_as_list(self):
+    def test_add_markers_as_list(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         marker_list = []
         for i in range(12):
@@ -166,7 +166,7 @@ class TestMarkers:
 
 class Test_permanent_markers:
 
-    def test_add_permanent_marker(self):
+    def test_add_permanent_marker(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         m = markers.point(x=5, y=5)
         s.add_marker(m, permanent=True)
@@ -178,7 +178,7 @@ class Test_permanent_markers:
         s.add_marker(m, permanent=True, plot_marker=False)
         assert list(s.metadata.Markers)[0][1] == m
 
-    def test_remove_permanent_marker_name(self):
+    def test_remove_permanent_marker_name(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         m = markers.point(x=5, y=5)
         m.name = 'test'
@@ -187,7 +187,7 @@ class Test_permanent_markers:
         del s.metadata.Markers.test
         assert len(list(s.metadata.Markers)) == 0
 
-    def test_permanent_marker_names(self):
+    def test_permanent_marker_names(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         m0 = markers.point(x=5, y=5)
         m1 = markers.point(x=5, y=5)
@@ -200,14 +200,14 @@ class Test_permanent_markers:
         assert s.metadata.Markers.test1 == m1
         assert m1.name == 'test1'
 
-    def test_add_permanent_marker_twice(self):
+    def test_add_permanent_marker_twice(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         m = markers.point(x=5, y=5)
         s.add_marker(m, permanent=True)
         with pytest.raises(ValueError):
             s.add_marker(m, permanent=True)
 
-    def test_add_permanent_marker_twice_different_signal(self):
+    def test_add_permanent_marker_twice_different_signal(self, mpl_cleanup):
         s0 = Signal1D(np.arange(10))
         s1 = Signal1D(np.arange(10))
         m = markers.point(x=5, y=5)
@@ -215,7 +215,7 @@ class Test_permanent_markers:
         with pytest.raises(ValueError):
             s1.add_marker(m, permanent=True)
 
-    def test_add_several_permanent_markers(self):
+    def test_add_several_permanent_markers(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         m_point = markers.point(x=5, y=5)
         m_line = markers.line_segment(x1=5, x2=10, y1=5, y2=10)
@@ -237,7 +237,7 @@ class Test_permanent_markers:
         with pytest.raises(ValueError):
             s.add_marker(m_rect, permanent=True)
 
-    def test_add_markers_as_list(self):
+    def test_add_markers_as_list(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         marker_list = []
         for i in range(10):
@@ -245,7 +245,7 @@ class Test_permanent_markers:
         s.add_marker(marker_list, permanent=True)
         assert len(s.metadata.Markers) == 10
 
-    def test_add_markers_as_list_add_same_twice(self):
+    def test_add_markers_as_list_add_same_twice(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         marker_list = []
         for i in range(10):
@@ -254,7 +254,7 @@ class Test_permanent_markers:
         with pytest.raises(ValueError):
             s.add_marker(marker_list, permanent=True)
 
-    def test_add_markers_as_list_add_different_twice(self):
+    def test_add_markers_as_list_add_different_twice(self, mpl_cleanup):
         s = Signal1D(np.arange(10))
         marker_list0 = []
         for i in range(10):
@@ -267,13 +267,13 @@ class Test_permanent_markers:
         s.add_marker(marker_list1, permanent=True)
         assert len(s.metadata.Markers) == 20
 
-    def test_add_permanent_marker_signal2d(self):
+    def test_add_permanent_marker_signal2d(self, mpl_cleanup):
         s = Signal2D(np.arange(100).reshape(10, 10))
         m = markers.point(x=5, y=5)
         s.add_marker(m, permanent=True)
         assert list(s.metadata.Markers)[0][1] == m
 
-    def test_deepcopy_permanent_marker(self):
+    def test_deepcopy_permanent_marker(self, mpl_cleanup):
         x, y, color, name = 2, 9, 'blue', 'test_point'
         s = Signal2D(np.arange(100).reshape(10, 10))
         m = markers.point(x=x, y=y, color=color)
@@ -370,13 +370,12 @@ def _test_plot_rectange_markers():
 
 
 @pytest.mark.mpl_image_compare(
-    baseline_dir=baseline_dir, tolerance=default_tol)
-def test_plot_rectange_markers():
+    baseline_dir=baseline_dir, tolerance=default_tol, style=style_pytest_mpl)
+def test_plot_rectange_markers(mpl_cleanup):
     im = _test_plot_rectange_markers()
     return im._plot.signal_plot.figure
 
 
-@cleanup
 @update_close_figure
 def test_plot_rectange_markers_close():
     return _test_plot_rectange_markers()  # return for @update_close_figure
@@ -396,13 +395,12 @@ def _test_plot_point_markers():
 
 
 @pytest.mark.mpl_image_compare(
-    baseline_dir=baseline_dir, tolerance=default_tol)
-def test_plot_point_markers():
+    baseline_dir=baseline_dir, tolerance=default_tol, style=style_pytest_mpl)
+def test_plot_point_markers(mpl_cleanup):
     s = _test_plot_point_markers()
     return s._plot.signal_plot.figure
 
 
-@cleanup
 @update_close_figure
 def test_plot_point_markers_close():
     return _test_plot_point_markers()
@@ -421,20 +419,19 @@ def _test_plot_text_markers():
 
 
 @pytest.mark.mpl_image_compare(
-    baseline_dir=baseline_dir, tolerance=default_tol)
-def test_plot_text_markers_nav():
+    baseline_dir=baseline_dir, tolerance=default_tol, style=style_pytest_mpl)
+def test_plot_text_markers_nav(mpl_cleanup):
     s = _test_plot_text_markers()
     return s._plot.navigator_plot.figure
 
 
 @pytest.mark.mpl_image_compare(
-    baseline_dir=baseline_dir, tolerance=default_tol)
-def test_plot_text_markers_sig():
+    baseline_dir=baseline_dir, tolerance=default_tol, style=style_pytest_mpl)
+def test_plot_text_markers_sig(mpl_cleanup):
     s = _test_plot_text_markers()
     return s._plot.signal_plot.figure
 
 
-@cleanup
 @update_close_figure
 def test_plot_text_markers_close():
     return _test_plot_text_markers()
@@ -456,13 +453,12 @@ def _test_plot_line_markers():
 
 
 @pytest.mark.mpl_image_compare(
-    baseline_dir=baseline_dir, tolerance=default_tol)
-def test_plot_line_markers():
+    baseline_dir=baseline_dir, tolerance=default_tol, style=style_pytest_mpl)
+def test_plot_line_markers(mpl_cleanup):
     im = _test_plot_line_markers()
     return im._plot.signal_plot.figure
 
 
-@cleanup
 @update_close_figure
 def test_plot_line_markers_close():
     return _test_plot_line_markers()
