@@ -2,10 +2,10 @@ from unittest import mock
 
 import numpy as np
 import pytest
-from matplotlib.testing.decorators import cleanup
 
 import hyperspy.api as hs
 from hyperspy.misc.utils import slugify
+from hyperspy.decorators import lazifyTestClass
 
 
 class TestModelJacobians:
@@ -308,20 +308,6 @@ class TestModel1D:
         np.testing.assert_array_equal(m.convolution_axis, np.arange(7, 23))
         np.testing.assert_equal(ll_axis.value2index.call_args[0][0], 0)
 
-    @pytest.mark.parallel
-    def test_notebook_interactions(self):
-        ipywidgets = pytest.importorskip("ipywidgets", minversion="5.0")
-        ipython = pytest.importorskip("IPython")
-        from IPython import get_ipython
-        ip = get_ipython()
-        if ip is None or not getattr(ip, 'kernel', None):
-            pytest.skip("Not attached to notebook")
-        m = self.model
-        m.notebook_interaction()
-        m.append(hs.model.components1D.Offset())
-        m[0].notebook_interaction()
-        m[0].offset.notebook_interaction()
-
     def test_access_component_by_name(self):
         m = self.model
         g1 = hs.model.components1D.Gaussian()
@@ -600,6 +586,7 @@ class TestModel2D:
         np.testing.assert_allclose(gt.sigma_y.value, 2.)
 
 
+@lazifyTestClass
 class TestModelFitBinned:
 
     def setup_method(self, method):
@@ -728,6 +715,7 @@ class TestModelFitBinned:
             self.m.fit(method="dummy")
 
 
+@lazifyTestClass
 class TestModelWeighted:
 
     def setup_method(self, method):
@@ -869,6 +857,7 @@ class TestModelScalarVariance:
         np.testing.assert_allclose(self.m.red_chisq.data, 0.86206965)
 
 
+@lazifyTestClass
 class TestModelSignalVariance:
 
     def setup_method(self, method):
@@ -894,6 +883,7 @@ class TestModelSignalVariance:
                                    0.91453032901427167)
 
 
+@lazifyTestClass
 class TestMultifit:
 
     def setup_method(self, method):
@@ -1091,6 +1081,7 @@ class TestAsSignal:
                                                         np.ones((2, 5)) * 2]))
 
 
+@lazifyTestClass
 class TestCreateModel:
 
     def setup_method(self, method):
@@ -1110,36 +1101,31 @@ class TestAdjustPosition:
         self.s = hs.signals.Signal1D(np.random.rand(10, 10, 20))
         self.m = self.s.create_model()
 
-    @cleanup
-    def test_enable_adjust_position(self):
+    def test_enable_adjust_position(self, mpl_cleanup):
         self.m.append(hs.model.components1D.Gaussian())
         self.m.enable_adjust_position()
         assert len(self.m._position_widgets) == 1
         # Check that both line and label was added
         assert len(list(self.m._position_widgets.values())[0]) == 2
 
-    @cleanup
-    def test_disable_adjust_position(self):
+    def test_disable_adjust_position(self, mpl_cleanup):
         self.m.append(hs.model.components1D.Gaussian())
         self.m.enable_adjust_position()
         self.m.disable_adjust_position()
         assert len(self.m._position_widgets) == 0
 
-    @cleanup
-    def test_enable_all(self):
+    def test_enable_all(self, mpl_cleanup):
         self.m.append(hs.model.components1D.Gaussian())
         self.m.enable_adjust_position()
         self.m.append(hs.model.components1D.Gaussian())
         assert len(self.m._position_widgets) == 2
 
-    @cleanup
-    def test_enable_all_zero_start(self):
+    def test_enable_all_zero_start(self, mpl_cleanup):
         self.m.enable_adjust_position()
         self.m.append(hs.model.components1D.Gaussian())
         assert len(self.m._position_widgets) == 1
 
-    @cleanup
-    def test_manual_close(self):
+    def test_manual_close(self, mpl_cleanup):
         self.m.append(hs.model.components1D.Gaussian())
         self.m.append(hs.model.components1D.Gaussian())
         self.m.enable_adjust_position()
