@@ -18,14 +18,16 @@
 
 import numpy as np
 import numpy.testing
-import nose.tools as nt
+
 
 import hyperspy.api as hs
+from hyperspy.decorators import lazifyTestClass
 
 
+@lazifyTestClass
 class Test_Estimate_Elastic_Scattering_Threshold:
 
-    def setUp(self):
+    def setup_method(self, method):
         # Create an empty spectrum
         s = hs.signals.EELSSpectrum(np.zeros((3, 2, 1024)))
         energy_axis = s.axes_manager.signal_axes[0]
@@ -53,8 +55,8 @@ class Test_Estimate_Elastic_Scattering_Threshold:
             tol=0.00001,
         )
         np.testing.assert_allclose(thr.data, 2.5, atol=10e-3)
-        nt.assert_equal(thr.metadata.Signal.signal_type, "")
-        nt.assert_equal(thr.axes_manager.signal_dimension, 0)
+        assert thr.metadata.Signal.signal_type == ""
+        assert thr.axes_manager.signal_dimension == 0
 
     def test_min_in_window_without_smoothing_single_spectrum(self):
         s = self.signal.inav[0, 0]
@@ -81,15 +83,15 @@ class Test_Estimate_Elastic_Scattering_Threshold:
         data = s.estimate_elastic_scattering_threshold(window=1.5,
                                                        tol=0.001,
                                                        ).data
-        nt.assert_true(np.all(np.isnan(data)))
+        assert np.all(np.isnan(data))
 
     def test_estimate_elastic_scattering_intensity(self):
         s = self.signal
         threshold = s.estimate_elastic_scattering_threshold(window=4.)
         # Threshold is nd signal
         t = s.estimate_elastic_scattering_intensity(threshold=threshold)
-        nt.assert_equal(t.metadata.Signal.signal_type, "")
-        nt.assert_equal(t.axes_manager.signal_dimension, 0)
+        assert t.metadata.Signal.signal_type == ""
+        assert t.axes_manager.signal_dimension == 0
         np.testing.assert_array_almost_equal(t.data, 249999.985133)
         # Threshold is signal, 1 spectrum
         s0 = s.inav[0]
@@ -101,9 +103,10 @@ class Test_Estimate_Elastic_Scattering_Threshold:
         np.testing.assert_array_almost_equal(t.data, 249999.985133)
 
 
+@lazifyTestClass
 class TestEstimateZLPCentre:
 
-    def setUp(self):
+    def setup_method(self, method):
         s = hs.signals.EELSSpectrum(np.diag(np.arange(1, 11)))
         s.axes_manager[-1].scale = 0.1
         s.axes_manager[-1].offset = 100
@@ -116,13 +119,14 @@ class TestEstimateZLPCentre:
                                    np.arange(100,
                                              101,
                                              0.1))
-        nt.assert_equal(zlpc.metadata.Signal.signal_type, "")
-        nt.assert_equal(zlpc.axes_manager.signal_dimension, 0)
+        assert zlpc.metadata.Signal.signal_type == ""
+        assert zlpc.axes_manager.signal_dimension == 0
 
 
+@lazifyTestClass
 class TestAlignZLP:
 
-    def setUp(self):
+    def setup_method(self, method):
         s = hs.signals.EELSSpectrum(np.zeros((10, 100)))
         self.scale = 0.1
         self.offset = -2
@@ -165,8 +169,8 @@ class TestAlignZLP:
                                also_align=[s2],
                                show_progressbar=None)
         zlpc = s2.estimate_zero_loss_peak_centre()
-        nt.assert_equal(zlpc.data.mean(), 0)
-        nt.assert_equal(zlpc.data.std(), 0)
+        assert zlpc.data.mean() == 0
+        assert zlpc.data.std() == 0
 
     def test_align_zero_loss_peak_with_spike_signal_range(self):
         s = self.signal
@@ -180,12 +184,13 @@ class TestAlignZLP:
         # Max value in the original spectrum is 12, but due to the aligning
         # the peak is split between two different channels. So 8 is the
         # maximum value for the aligned spectrum
-        nt.assert_true(np.allclose(zlp_max, 8))
+        assert np.allclose(zlp_max, 8)
 
 
+@lazifyTestClass
 class TestPowerLawExtrapolation:
 
-    def setUp(self):
+    def setup_method(self, method):
         s = hs.signals.EELSSpectrum(0.1 * np.arange(50, 250, 0.5) ** -3.)
         s.metadata.Signal.binned = False
         s.axes_manager[-1].offset = 50
@@ -203,3 +208,13 @@ class TestPowerLawExtrapolation:
         sc = self.s.isig[:300]
         s = sc.power_law_extrapolation(extrapolation_size=100)
         np.testing.assert_allclose(s.data, self.s.data, atol=10e-3)
+
+@lazifyTestClass
+class TestFourierRatioDeconvolution:
+
+    def test_running(self):
+        s = hs.signals.EELSSpectrum(np.arange(200))
+        s_ll = hs.signals.EELSSpectrum(np.zeros(100))
+        s_ll.data[18:23] = [3, 10, 20, 10, 3]
+        s_ll.axes_manager[0].offset = -20
+        s.fourier_ratio_deconvolution(s_ll)
